DEMIClustDEMIClust stores the probe clusters in a DEMIClust object.
DEMIExperiment object. Holds the DEMIExperiment object whose metadata
(such as normalized expression values) is used to cluster the probes.DEMIGroup object. Defines the groups that are used for clustering. The DEMIGroup
object uses CEL file names to determine which files belong to which group. It uses
grep function to locate the group names from the CEL file names.function. Defines the function used for clustering. The user can
build a custom clustering function. The input of the custom function needs
to be the same DEMIClust object and the output is a list of probes, where
each list corresponds to a specific cluster. The default function is demi.wilcox.test that
utilizes wilcox.test.list. Holds the probes of different clusters in a list.numeric. Sets the cut-off p-value used for determining statistical
significance of the probes when clustering the probes into clusters. Default is 0.05.