DEMIGroupDEMIGroup holds the information about the groups. Such as
the column indexes of both groups and names of the groups.
character. Holds the name of group A.character. Holds the name of group B.numeric. A vector of column indexes belonging to group A.numeric. A vector of column indexes belonging to group B.character. Holds the names of custom groups created by
the user.