maxprobes analysisadjust4maxprobes adjust the number of probes if the maxprobes has been
set in the DEMIExperiment object. It is used internally in DEMI analysis.
adjust4maxprobes(targetMatches, maxprobes)data.frame. The original number of probes per target stored in a data.frame.numeric. Specifies the maximum number of probes a target a target is adjusted against.data.frame with the number of probes per target have been adjusted by maxprobes.