totalMatches_cluster calculates the number of matches in the cluster in DEMI
analysis. It is used internally in DEMI analysis.
totalMatches_cluster(cluster, blatTable)vector. A vector of probe ID's in the cluster.data.frame. A data.frame with alignment information.data.frame that represents the number of probes for each target in the cluster.